@@ -6,6 +6,7 @@ from datetime import datetime
 from hashlib import sha256
 import csv
 
+requests.packages.urllib3.util.connection.HAS_IPV6 = False
 
 class SocketEventBreeze(socketio.ClientNamespace):
 
@@ -1061,7 +1062,7 @@ class ApificationBreeze():
                 if((expiry_date=="" or expiry_date==None)  and (strike_price=="" or strike_price==None) and (right=="" or right==None)):
                     response = {"Success": "", "Status": 500, "Error": "Atleast two inputs are required out of Expiry-Date, Right & Strike-Price. All three cannot be empty'."}
                     return response
-                elif((expiry_date!="" or expiry_date!=None) and (strike_price=="" or  strike_price==None) and (right=="" or right==None)):
+                elif((expiry_date!="" and expiry_date!=None) and (strike_price=="" or  strike_price==None) and (right=="" or right==None)):
                     response = {"Success": "", "Status": 500, "Error": "Either Right or Strike-Price cannot be empty."}
                     return response
                 elif((expiry_date == "" or expiry_date == None) and (strike_price!="" or strike_price!=None) and (right=="" or right == None)):
@@ -1070,7 +1071,7 @@ class ApificationBreeze():
                 elif((expiry_date=="" or expiry_date==None) and (strike_price=="" or strike_price==None) and (right!=None or right!="")):
                     response = {"Success": "", "Status": 500, "Error": "Either Expiry-Date or Strike-Price cannot be empty."}
                     return response
-                elif((right!="" or right!=None) and (right!="call" and right!="put" and right!="others")):
+                elif((right!="" and right!=None) and (right!="call" and right!="put" and right!="others")):
                     response = {"Success": "", "Status": 500, "Error": "Right should be either 'call', 'put', or 'others'."}
                     return response
             body = {
